
# trim changelog included in binary rpms
%global _changelog_trimtime %(date +%s -d "1 year ago")

Name:    kdepim
Summary: KDE PIM (Personal Information Manager) applications
Epoch:   7
Version: 4.11.4
Release: 1%{?dist}

License: GPLv2
URL:     http://www.kde.org/
%global revision %(echo %{version} | cut -d. -f3)
%if %{revision} >= 50
%global stable unstable
%else
%global stable stable
%endif
Source0: http://download.kde.org/%{stable}/%{version}/src/%{name}-%{version}.tar.xz

# revert http://websvn.kde.org/?view=revision&revision=1072331 (rebased to 4.6)
# for kopete-cryptography (mostly)
Patch0:  kdepim-4.10.90-install_kleopatra_headers.patch

## upstream patches

Provides: kdepim4 = %{version}-%{release}

Requires: %{name}-libs%{?_isa} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires: kde-runtime%{?_kde4_version: >= %{_kde4_version}}
Requires: kate-part%{?_kde4_version: >= %{_kde4_version}}
# beware bootstrapping (ie, build kdepim-runtime first)
Requires: kdepim4-runtime >= %{version}

BuildRequires: bison flex
BuildRequires: boost-devel
BuildRequires: chrpath
BuildRequires: cyrus-sasl-devel
BuildRequires: desktop-file-utils
BuildRequires: gettext
BuildRequires: gpgme-devel
BuildRequires: grantlee-devel
BuildRequires: kactivities-devel >= %{version}
BuildRequires: kdepimlibs-devel >= %{version} 
BuildRequires: kde-baseapps-devel >= %{version}
BuildRequires: nepomuk-widgets-devel >= %{version}
BuildRequires: libassuan-devel
BuildRequires: pkgconfig(akonadi) > 1.9.51
BuildRequires: pkgconfig(libical)
BuildRequires: pkgconfig(libstreamanalyzer) pkgconfig(libstreams)
BuildRequires: pkgconfig(libxslt)
BuildRequires: pkgconfig(link-grammar)
BuildRequires: pkgconfig(qca2)
BuildRequires: pkgconfig(soprano)
BuildRequires: pkgconfig(xpm) pkgconfig(xscrnsaver)
%if 0%{?fedora}
BuildRequires: prison-devel
%endif
BuildRequires: python-devel
BuildRequires: zlib-devel

# kmail searches for gpg instead of gpg2, breaking email encryption
# http://bugzilla.redhat.com/630249 
# TODO: patch to use gpg2 (unconditionally or as in addition to gpg)
Requires: gnupg
%if 0%{?fedora}
##Optional bits
Requires: pinentry-gui
Requires: spambayes
#Requires: spamassassin
#{?fedora:Requires: bogofilter}
%endif

%description
%{summary}, including:
* akregator: feed aggregator
* blogilo: blogging application, focused on simplicity and usability
* kmail: email client
* knode: newsreader
* knotes: sticky notes for the desktop
* kontact: integrated PIM management
* korganizer: journal, appointments, events, todos

%package libs
Summary: %{name} runtime libraries
Requires: %{name} = %{?epoch:%{epoch}:}%{version}-%{release}
#{?_kde4_version:Requires: kdepimlibs-akonadi%{?_isa} >= %{_kde4_version}}
%description libs
%{summary}.

%package devel
Summary:  %{name} development files
Requires: %{name}-libs%{?_isa} = %{?epoch:%{epoch}:}%{version}-%{release}
%description devel
%{summary}.


%prep
%setup -q -n kdepim-%{version}%{?pre}

%patch0 -p1 -b .install_kleopatra_headers


%build
mkdir -p %{_target_platform}
pushd %{_target_platform}
# We disable kdepim-mobile because it doesn't actually work yet. (#717694)
# Plus, it should probably go to a subpackage once it actually does work.
%{cmake_kde4} \
  -DKDEPIM_BUILD_MOBILE:BOOL=OFF \
  ..
popd

make %{?_smp_mflags} -C %{_target_platform}


%install
make install/fast DESTDIR=%{buildroot} -C %{_target_platform}

%find_lang %{name} --with-kde --without-mo --all-name

# not sure where this is coming from... -- Rex
chrpath --list   %{buildroot}%{_kde4_bindir}/kabc2mutt && \
chrpath --delete %{buildroot}%{_kde4_bindir}/kabc2mutt


%check
for f in %{buildroot}%{_kde4_datadir}/applications/kde4/*.desktop ; do
  desktop-file-validate $f
done


%post
touch --no-create %{_kde4_iconsdir}/hicolor &> /dev/null ||:
touch --no-create %{_kde4_iconsdir}/oxygen &> /dev/null ||:

%posttrans
gtk-update-icon-cache %{_kde4_iconsdir}/hicolor &> /dev/null ||:
gtk-update-icon-cache %{_kde4_iconsdir}/oxygen &> /dev/null ||:
update-desktop-database -q &> /dev/null ||:

%postun
if [ $1 -eq 0 ] ; then
  touch --no-create %{_kde4_iconsdir}/hicolor &> /dev/null ||:
  touch --no-create %{_kde4_iconsdir}/oxygen &> /dev/null ||:
  gtk-update-icon-cache %{_kde4_iconsdir}/hicolor &> /dev/null ||:
  gtk-update-icon-cache %{_kde4_iconsdir}/oxygen &> /dev/null ||:
  update-desktop-database -q &> /dev/null ||:
fi

%files -f %{name}.lang
%doc README 
%doc COPYING
%{_kde4_bindir}/*
%{_kde4_libdir}/kde4/*.so
%{_kde4_libdir}/akonadi/contact/
%{_kde4_datadir}/akonadi/agents/*.desktop
%{_kde4_datadir}/applications/kde4/*.desktop
%{_kde4_appsdir}/akonadi_archivemail_agent/
%{_kde4_appsdir}/akonadi_mailfilter_agent/
%{_kde4_appsdir}/akonadi_sendlater_agent/
%{_kde4_appsdir}/akonadiconsole/
%{_kde4_appsdir}/akregator/
%{_kde4_appsdir}/akregator_sharemicroblog_plugin/
%{_kde4_appsdir}/blogilo/
%{_kde4_appsdir}/composereditor/
%{_kde4_appsdir}/desktoptheme/default/widgets/*
%{_kde4_appsdir}/headerthemeeditor/
%{_kde4_appsdir}/kaddressbook/
%{_kde4_appsdir}/kalarm/
%{_kde4_appsdir}/kconf_update/*
%{_kde4_appsdir}/kdepimwidgets/
%{_kde4_appsdir}/kjots/
%{_kde4_appsdir}/kleopatra/
%{_kde4_appsdir}/kmail2/
%{_kde4_appsdir}/kmailcvt/
%{_kde4_appsdir}/knode/
%{_kde4_appsdir}/knotes/
%{_kde4_appsdir}/kontact/
%{_kde4_appsdir}/kontactsummary/
%{_kde4_appsdir}/korgac/
%{_kde4_appsdir}/korganizer/
%{_kde4_appsdir}/ktimetracker/
%{_kde4_appsdir}/ktnef/
%{_kde4_appsdir}/kwatchgnupg/
%{_kde4_appsdir}/libkleopatra/
%{_kde4_appsdir}/libmessageviewer/
%{_kde4_appsdir}/messagelist/
%{_kde4_appsdir}/messageviewer/
%{_kde4_appsdir}/pimsettingexporter/
%{_datadir}/dbus-1/interfaces/*.xml
%{_kde4_datadir}/autostart/*.desktop
%{_kde4_datadir}/config/*rc
%{_kde4_datadir}/config.kcfg/*
# directory owned by kdepim-runtime
%{_kde4_datadir}/ontology/kde/messagetag.*
%{_kde4_iconsdir}/hicolor/*/*/*
%{_kde4_iconsdir}/locolor/*/*/*
%{_kde4_iconsdir}/oxygen/*/*/*
%{_kde4_datadir}/kde4/services/*
%{_kde4_datadir}/kde4/servicetypes/*.desktop
%{_sysconfdir}/dbus-1/system.d/org.kde.kalarmrtcwake.conf
%{_kde4_libexecdir}/kalarm_helper
%{_datadir}/dbus-1/system-services/org.kde.kalarmrtcwake.service
%{_datadir}/polkit-1/actions/org.kde.kalarmrtcwake.policy
%{_mandir}/man*/*.gz

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%files libs
%{_kde4_libdir}/lib*.so.*
%{_kde4_libdir}/kde4/plugins/accessible/
%{_kde4_libdir}/kde4/plugins/designer/*.so
%{_kde4_libdir}/kde4/plugins/grantlee/

%files devel
%{_kde4_includedir}/*
%{_kde4_libdir}/lib*.so


%changelog
* Fri Dec 13 2013 Rex Dieter <rdieter@fedoraproject.org> - 7:4.11.4-1
- 4.11.4

* Sat Nov 02 2013 Rex Dieter <rdieter@fedoraproject.org> - 7:4.11.3-1
- 4.11.3

* Sat Sep 28 2013 Rex Dieter <rdieter@fedoraproject.org> - 7:4.11.2-1
- 4.11.2

* Wed Sep 04 2013 Rex Dieter <rdieter@fedoraproject.org> - 7:4.11.1-1
- 4.11.1

* Thu Aug 08 2013 Than Ngo <than@redhat.com> - 4.11.0-1
- 4.11.0

* Tue Jul 30 2013 Petr Machata <pmachata@redhat.com> - 7:4.10.97-2
- Rebuild for boost 1.54.0

* Thu Jul 25 2013 Rex Dieter <rdieter@fedoraproject.org> - 7:4.10.97-1
- 4.10.97

* Tue Jul 23 2013 Rex Dieter <rdieter@fedoraproject.org> - 7:4.10.95-1
- 4.10.95

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 7:4.10.90-2
- Perl 5.18 rebuild

* Fri Jun 28 2013 Rex Dieter <rdieter@fedoraproject.org> - 7:4.10.90-1
- 4.10.90

* Sat Jun 01 2013 Rex Dieter <rdieter@fedoraproject.org> - 7:4.10.4-1
- 4.10.4

* Fri May 10 2013 Rex Dieter <rdieter@fedoraproject.org> -7:4.10.3-2
- pull in some upstream fixes

* Mon May 06 2013 Than Ngo <than@redhat.com> - 7:4.10.3-1
- 4.10.3

* Tue Apr 16 2013 Daniel Vrátil <dvratil@redhat.com> 7:4.10.2-3
- multipart messages displayed twice in KMail (kde#318182)

* Mon Apr 08 2013 Rex Dieter <rdieter@fedoraproject.org> 7:4.10.2-2
- pull in some upstream fixes, in particular...
- address completion from akonadi regresssion (kde#259949)

* Mon Apr 01 2013 Rex Dieter <rdieter@fedoraproject.org> - 7:4.10.2-1
- 4.10.2

* Sat Mar 02 2013 Rex Dieter <rdieter@fedoraproject.org> - 7:4.10.1-1
- 4.10.1

* Fri Feb 01 2013 Rex Dieter <rdieter@fedoraproject.org> - 7:4.10.0-1
- 4.10.0

* Tue Jan 22 2013 Rex Dieter <rdieter@fedoraproject.org> - 7:4.9.98-1
- 4.9.98

* Fri Jan 04 2013 Rex Dieter <rdieter@fedoraproject.org> - 7:4.9.97-1
- 4.9.97

* Sun Dec 23 2012 Rex Dieter <rdieter@fedoraproject.org> 4.9.95-2
- 4.9.95

* Tue Dec 04 2012 Rex Dieter <rdieter@fedoraproject.org> 4.9.90-1
- 4.9.90

* Mon Dec 03 2012 Than Ngo <than@redhat.com> - 4.9.4-1
- 4.9.4

* Mon Nov 12 2012 Rex Dieter <rdieter@fedoraproject.org> 7:4.9.3-2
- move importwizard.desktop out of Lost+Found

* Sat Nov 03 2012 Rex Dieter <rdieter@fedoraproject.org> - 7:4.9.3-1
- 4.9.3

* Thu Nov 1 2012 Lukáš Tinkl<ltinkl@redhat.com> 7:4.9.2-2
- build against prison only under Fedora

* Sat Sep 29 2012 Rex Dieter <rdieter@fedoraproject.org> - 7:4.9.2-1
- 4.9.2

* Mon Sep 03 2012 Than Ngo <than@redhat.com> - 7:4.9.1-1
- 4.9.1

* Sat Aug 25 2012 Rex Dieter <rdieter@fedoraproject.org> 7:4.9.0-4
- BR: prison-devel

* Sat Aug 25 2012 Rex Dieter <rdieter@fedoraproject.org> 7:4.9.0-3
- filtering removes email's content (kde#295484)

* Fri Aug 17 2012 Lukas Tinkl <ltinkl@redhat.com> - 7:4.9.0-2
- Resolves: #813257 - Ktimetracker shows only an empty window

* Thu Jul 26 2012 Lukas Tinkl <ltinkl@redhat.com> - 7:4.9.0-1
- 4.9.0

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7:4.8.97-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jul 12 2012 Rex Dieter <rdieter@fedoraproject.org> - 7:4.8.97-1
- 4.8.97

* Fri Jul 06 2012 Rex Dieter <rdieter@fedoraproject.org> 7:4.8.95-3
- .spec cleanup

* Thu Jul 05 2012 Rex Dieter <rdieter@fedoraproject.org> 7:4.8.95-2
- upstream filter-rework patch

* Wed Jun 27 2012 Jaroslav Reznik <jreznik@redhat.com> - 7:4.8.95-1
- 4.8.95

* Sat Jun 09 2012 Rex Dieter <rdieter@fedoraproject.org> - 7:4.8.90-1
- 4.8.90

* Sun Jun 03 2012 Jaroslav Reznik <jreznik@redhat.com> - 7:4.8.80-1
- 4.8.80
- add locolor icons again
- fix appsdir filelist

* Mon Apr 30 2012 Rex Dieter <rdieter@fedoraproject.org> 7:4.8.3-2
- s/kdebase-runtime/kde-runtime/

* Mon Apr 30 2012 Jaroslav Reznik <jreznik@redhat.com> - 7:4.8.3-1
- 4.8.3

* Fri Mar 30 2012 Rex Dieter <rdieter@fedoraproject.org> - 7:4.8.2-1
- 4.8.2

* Thu Mar 29 2012 Rex Dieter <rdieter@fedoraproject.org> 4.8.1-4
- Kalarm not allowing editing or deleting of alarms (#808066)

* Mon Mar 12 2012 Jaroslav Reznik <jreznik@redhat.com> - 4.8.1-3
- fix version
- remove g++47 patch as it's already applied upstream

* Tue Mar 06 2012 Than Ngo <than@redhat.com> - 4.8.1-2
- respin

* Mon Mar 05 2012 Jaroslav Reznik <jreznik@redhat.com> - 7:4.8.1-1
- 4.8.1
- add missing ontologies

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7:4.8.0-2
- Rebuilt for c++ ABI breakage

* Sun Jan 22 2012 Rex Dieter <rdieter@fedoraproject.org> - 7:4.8.0-1
- 4.8.0

* Wed Jan 04 2012 Radek Novacek <rnovacek@redhat.com> - 7:4.7.97-1
- 4.7.97
- fix build with g++ 4.7

* Wed Dec 21 2011 Radek Novacek <rnovacek@redhat.com> - 7:4.7.95-1
- 4.7.95

* Sun Dec 04 2011 Rex Dieter <rdieter@fedoraproject.org> - 7:4.7.90-1
- 4.7.90

* Fri Nov 25 2011 Radek Novacek <rnovacek@redhat.com> 7:4.7.80-1
- 4.7.80 (beta 1)
- add BR: kdebase-devel
- drop "nepomuk disabled spam" patch, patched file not exists

* Sat Oct 29 2011 Rex Dieter <rdieter@fedoraproject.org> 7:4.7.3-1
- 4.7.3

* Mon Oct 24 2011 Rex Dieter <rdieter@fedoraproject.org> 7:4.7.2-7
- pkgconfig-style deps

* Sun Oct 16 2011 Kevin Kofler <Kevin@tigcc.ticalc.org> 7:4.7.2-6
- rebuild for patched Qt in Rawhide (#746252)

* Fri Oct 14 2011 Kevin Kofler <Kevin@tigcc.ticalc.org> 7:4.7.2-5
- fix KMail migration (kde#283563)

* Thu Oct 13 2011 Rex Dieter <rdieter@fedoraproject.org> 7:4.7.2-4
- disable akonadi nepomuk/strigi notification spam

* Sat Oct 08 2011 Rex Dieter <rdieter@fedoraproject.org> 7:4.7.2-2
- Requires: kate-part

* Tue Oct 04 2011 Rex Dieter <rdieter@fedoraproject.org> 7:4.7.2-1
- 4.7.2

* Fri Sep 02 2011 Than Ngo <than@redhat.com> - 7:4.7.1-1
- 4.7.1

* Tue Jul 26 2011 Jaroslav Reznik <jreznik@redhat.com> 7:4.7.0-1
- 4.7.0

* Mon Jul 11 2011 Jaroslav Reznik <jreznik@redhat.com> 7:4.6.95-1
- 4.6.95

* Thu Jun 30 2011 Rex Dieter <rdieter@fedoraproject.org> 7:4.6.90-1
- 4.6.90

* Wed Jun 29 2011 Kevin Kofler <Kevin@tigcc.ticalc.org> 7:4.6.0-2
- Disable kdepim-mobile until it actually works (#717694)

* Fri Jun 10 2011 Rex Dieter <rdieter@fedoraproject.org> 7:4.6.0-1
- 4.6.0

* Fri May 13 2011 Rex Dieter <rdieter@fedoraproject.org> 7:4.5.96-1
- 4.5.96 (4.6rc1)

* Tue May 10 2011 Rex Dieter <rdieter@fedoraproject.org> 7:4.5.95-2
- Requires: gnupg (#630249)

* Thu Apr 14 2011 Rex Dieter <rdieter@fedoraproject.org> 7:4.5.95-1
- 4.5.95 (4.6beta5)

* Thu Feb 24 2011 Rex Dieter <rdieter@fedoraproject.org> 7:4.5.94.1-4
- Provides: kde-l10n-kdepim

* Thu Feb 10 2011 Rex Dieter <rdieter@fedoraproject.org> 7:4.5.94.1-3
- Epoch++
- Requires: kdepim4-runtime

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Jan 11 2011 Rex Dieter <rdieter@fedoraproject.org> 4.5.94.1-1
- 4.5.94.1 (4.6beta4)

* Thu Dec 23 2010 Rex Dieter <rdieter@fedoraproject.org> 4.5.93-1
- 4.5.93 (4.6beta3)

* Wed Dec 08 2010 Kevin Kofler <Kevin@tigcc.ticalc.org> 4.5.85-2
- restore and rebase install-headers patch for kopete-cryptography (#660951)

* Sat Dec 04 2010 Thomas Janssen <thomasj@fedoraproject.org> 4.5.85-1
- 4.5.85 (4.6beta2)

* Wed Nov 24 2010 Rex Dieter <rdieter@fedoraproject.org> 4.5.80-1
- 4.5.80 (4.6beta1)

* Tue Nov 16 2010 Thomas Janssen <thomasj@fedoraproject.org> 4.4.93-5
- re-activated kdepim-devel for basket_kontact plugin

* Tue Oct 19 2010 Rex Dieter <rdieter@fedoraproject.org> 4.4.93-4
- own %%_libdir/akonadi/contact (#644540)

* Wed Sep 01 2010 Thomas Janssen <thomasj@fedoraproject.org> 4.4.93-3
- fixed botched obsoletes

* Wed Sep 01 2010 Rex Dieter <rdieter@fedoraproject.org> - 4.4.93-2
- fix Obsoletes: kdepim-devel
- BR: kdepimlibs-devel >= 4.5.1

* Tue Aug 31 2010 Thomas Janssen <thomasj@fedoraproject.org> 4.4.93-1
- 4.4.93 (4.5 beta3)

* Fri Aug 13 2010 Rex Dieter <rdieter@fedoraproject.org> - 4.4.92-1
- BR: libassuan2-devel

* Wed Aug 11 2010 Rex Dieter <rdieter@fedoraproject.org> - 4.4.92-1
- 4.4.92 (4.5 beta2)

* Tue Jul 06 2010 Rex Dieter <rdieter@fedoraproject.org> - 4.5-0.2.beta1
- Requires: kdebase-runtime

* Fri Jul 02 2010 Rex Dieter <rdieter@fedoraproject.org> - 4.5-0.1.beta1
- 4.5-beta1

* Tue Jun 29 2010 Rex Dieter <rdieter@fedoraproject.org> - 6:4.4.5-1
- 4.4.5

* Sun May 30 2010 Than Ngo <than@redhat.com> - 6:4.4.4-1
- 4.4.4

* Tue May 04 2010 Lukas Tinkl <ltinkl@redhat.com> - 6:4.4.3-1.1
- rebuild against correct tag

* Fri Apr 30 2010 Jaroslav Reznik <jreznik@redhat.com> - 6:4.4.3-1
- 4.4.3

* Mon Mar 29 2010 Lukas Tinkl <ltinkl@redhat.com> - 6:4.4.2-1
- 4.4.2

* Tue Mar 02 2010 Lukas Tinkl <ltinkl@redhat.com> - 6:4.4.1-2
- tarball respin
- don't install an .so file into datadir

* Sat Feb 27 2010 Rex Dieter <rdieter@fedoraproject.org> - 6:4.4.1-1
- 4.4.1

* Fri Feb 19 2010 Rex Dieter <rdieter@fedoraproject.org> - 6:4.4.0-5
- un-arch kdepim-runtime dep (it's not multilib'd)

* Sat Feb 13 2010 Kevin Kofler <Kevin@tigcc.ticalc.org> - 6:4.4.0-4
- ship -devel package again, kopete-cryptography needs it to build (#564406)

* Tue Feb 09 2010 Rex Dieter <rdieter@fedoraproject.org> - 6:4.4.0-3
- drop BR: gnokii-devel (not used)
- drop var-tracking patch (gcc fixed)

* Tue Feb 09 2010 Lukas Tinkl <ltinkl@redhat.com> - 6:4.4.0-2
- fix Kontact startup

* Fri Feb 05 2010 Than Ngo <than@redhat.com> - 6:4.4.0-1
- 4.4.0
